pub struct NodeElement {
pub tag: String,
pub attrs: Option<HashMap<String, Option<String>>>,
pub children: Option<Vec<Node>>,
}Expand description
This object represents a DOM element node.
Fields
tag: StringName of the DOM element. Available tags: a, aside, b, blockquote, br, code, em, figcaption, figure, h3, h4, hr, i, iframe, img, li, ol, p, pre, s, strong, u, ul, video.
attrs: Option<HashMap<String, Option<String>>>Optional. Attributes of the DOM element.
Key of object represents name of attribute, value represents value of attribute.
Available attributes: href, src.
children: Option<Vec<Node>>Optional. List of child nodes for the DOM element.